# SUSY Example

In this example we will train Decision Tree and Random Forest models on the SUSY dataset from the LibSVM repository, using both `scikit-learn` and `snap-ml-local`. 

## Download the Data

Download and decompress the data from the LIBSVM repository:
```
mkdir data
cd data
wget https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/binary/SUSY.bz2
bunzip2 SUSY.bz2
cd ../
```

## PreProcess the data

We first perform some data pre-processing.

The entire pre-processing can be run by executing `python $CONDA_PREFIX/pai4sk/snap-ml-local/examples/example-susy/preprocess-susy.py`

Command to pre-process the data available in specific directory:
`python $CONDA_PREFIX/pai4sk/snap-ml-local/examples/example-susy/preprocess-susy.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.


## Training and Evaluating a Decision Tree Model

Run the example by executing `python $CONDA_PREFIX/pai4sk/snap-ml-local/examples/example-susy/example-susy-decision-tree.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/snap-ml-local/examples/example-susy/example-susy-decision-tree.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

```
Data load time (s):  0.13
[Info] Training will run in single-threaded mode on CPU.
[snap] Training time (s):  50.13
[snap] Accuracy score:   0.7776
[sklearn] Training time (s):  358.53
[sklearn] Accuracy score:   0.7156
```

## Training and Evaluating a Random Forest Model

Run the example by executing `python $CONDA_PREFIX/pai4sk/snap-ml-local/examples/example-susy/example-susy-random-forest.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/snap-ml-local/examples/example-susy/example-susy-random-forest.py --data_path path/to/data --num_threads 10` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

```
Data load time (s):  0.20
[snap] Training time (s):  16.37
[snap] Accuracy score:   0.7966
[sklearn] Training time (s):  71.45
[sklearn] Accuracy score:   0.7848
```

Times will vary depending on the system architecture. 

&copy; Copyright IBM Corporation 2018
