# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018, 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from __future__ import print_function
import os
import pandas as pd
from sklearn.preprocessing import StandardScaler
from sklearn.model_selection import StratifiedShuffleSplit
from sklearn.preprocessing import normalize
import numpy as np

import argparse
from sklearn.datasets import load_svmlight_file

from snap_ml_mpi.Utils import dump_to_snap_format
defaultPath = os.getcwd()
CLI=argparse.ArgumentParser()
CLI.add_argument(
   "--data_path",
   type=str,
   default=defaultPath
)

args = CLI.parse_args()

print("Loading creditcard dataset...")
# Import the data from csv format
data = pd.read_csv(args.data_path + "/data/creditcard.csv")

# Standardize features by removing the mean and scaling to unit variance
data.iloc[:, 1:29] = StandardScaler().fit_transform(data.iloc[:, 1:29])

# Convert the data frame to its Numpy-array representation
data_matrix = data.as_matrix()
X = data_matrix[:, 1:29]
y = data_matrix[:, 30]

# Normalize the data
print('Normalizing data...')
X = normalize(X, norm="l1")

# Augment the data
print(X.shape)
print(y.shape)
Z = X
z = y
for i in range(100):
    Z = np.concatenate((Z, np.tile(X,1)))
    z = np.concatenate((z, np.tile(y,1)))
X = Z
y = z
print(Z.shape)
print(y.shape)

# Split the data in train and test
stratSplit = StratifiedShuffleSplit(n_splits=1, test_size=0.25, random_state=42)
for train_index, test_index in stratSplit.split(X, y):
    X_train, X_test = X[train_index], X[test_index]
    y_train, y_test = y[train_index], y[test_index]

print('Saving data in sklearn format...')

# Save the dense matrices
np.save(args.data_path + "/data/creditcard.augmented.X_train", X_train)
np.save(args.data_path + "/data/creditcard.augmented.X_test",  X_test)

# Save the labels
np.save(args.data_path + "/data/creditcard.augmented.y_train", y_train)
np.save(args.data_path + "/data/creditcard.augmented.y_test", y_test)

print('Saving data in distributed snap.ml format...')

# Save data in distributed snap.ml format
dump_to_snap_format(X_train, y_train, args.data_path + '/data/creditcard.augmented.train.snap')
dump_to_snap_format(X_test, y_test, args.data_path + '/data/creditcard.augmented.test.snap')

